Documentation
¶
Index ¶
- Constants
- func ConfigTmpDir() (string, error)
- type Artifact
- type Builder
- type Communicator
- func (c *Communicator) Download(src string, dst io.Writer) error
- func (c *Communicator) DownloadDir(src string, dst string, exclude []string) error
- func (c *Communicator) Start(ctx context.Context, remote *packer.RemoteCmd) error
- func (c *Communicator) Upload(dst string, src io.Reader, fi *os.FileInfo) error
- func (c *Communicator) UploadDir(dst string, src string, exclude []string) error
- type Config
- type FlatConfig
- type StepConnectAnka
- type StepCreateVM
- type StepSetHyperThreading
- type StepStartVM
- type StepTempDir
Constants ¶
const ( DEFAULT_DISK_SIZE = "40G" DEFAULT_RAM_SIZE = "4G" DEFAULT_CPU_COUNT = "2" )
const BuilderId = "packer.veertu-anka"
The unique ID for this builder.
const DEFAULT_BOOT_DELAY = "10s"
Variables ¶
This section is empty.
Functions ¶
func ConfigTmpDir ¶ added in v1.2.0
Types ¶
type Artifact ¶
type Artifact struct {
// contains filtered or unexported fields
}
Artifact represents an Anka image as the result of a Packer build.
type Builder ¶
type Builder struct {
// contains filtered or unexported fields
}
Builder represents a Packer Builder.
func (*Builder) ConfigSpec ¶ added in v1.2.0
func (b *Builder) ConfigSpec() hcldec.ObjectSpec
type Communicator ¶
type Communicator struct {
Config *Config
Client *client.Client
HostDir string
VMDir string
VMName string
}
func (*Communicator) DownloadDir ¶
func (c *Communicator) DownloadDir(src string, dst string, exclude []string) error
type Config ¶
type Config struct {
common.PackerConfig `mapstructure:",squash"`
Comm communicator.Config `mapstructure:",squash"`
InstallerApp string `mapstructure:"installer_app"`
SourceVMName string `mapstructure:"source_vm_name"`
VMName string `mapstructure:"vm_name"`
DiskSize string `mapstructure:"disk_size"`
RAMSize string `mapstructure:"ram_size"`
CPUCount string `mapstructure:"cpu_count"`
PortForwardingRules []struct {
PortForwardingGuestPort int `mapstructure:"port_forwarding_guest_port"`
PortForwardingHostPort int `mapstructure:"port_forwarding_host_port"`
PortForwardingRuleName string `mapstructure:"port_forwarding_rule_name"`
} `mapstructure:"port_forwarding_rules,omitempty"`
HWUUID string `mapstructure:"hw_uuid,omitempty"`
BootDelay string `mapstructure:"boot_delay"`
EnableHtt bool `mapstructure:"enable_htt"`
DisableHtt bool `mapstructure:"disable_htt"`
UpdateAddons bool `mapstructure:"update_addons"`
UseAnkaCP bool `mapstructure:"use_anka_cp"`
// contains filtered or unexported fields
}
func (*Config) FlatMapstructure ¶ added in v1.7.0
FlatMapstructure returns a new FlatConfig. FlatConfig is an auto-generated flat version of Config. Where the contents a fields with a `mapstructure:,squash` tag are bubbled up.
type FlatConfig ¶ added in v1.7.0
type FlatConfig struct {
PackerBuildName *string `mapstructure:"packer_build_name" cty:"packer_build_name" hcl:"packer_build_name"`
PackerBuilderType *string `mapstructure:"packer_builder_type" cty:"packer_builder_type" hcl:"packer_builder_type"`
PackerCoreVersion *string `mapstructure:"packer_core_version" cty:"packer_core_version" hcl:"packer_core_version"`
PackerDebug *bool `mapstructure:"packer_debug" cty:"packer_debug" hcl:"packer_debug"`
PackerForce *bool `mapstructure:"packer_force" cty:"packer_force" hcl:"packer_force"`
PackerOnError *string `mapstructure:"packer_on_error" cty:"packer_on_error" hcl:"packer_on_error"`
PackerUserVars map[string]string `mapstructure:"packer_user_variables" cty:"packer_user_variables" hcl:"packer_user_variables"`
PackerSensitiveVars []string `mapstructure:"packer_sensitive_variables" cty:"packer_sensitive_variables" hcl:"packer_sensitive_variables"`
Type *string `mapstructure:"communicator" cty:"communicator" hcl:"communicator"`
PauseBeforeConnect *string `mapstructure:"pause_before_connecting" cty:"pause_before_connecting" hcl:"pause_before_connecting"`
SSHHost *string `mapstructure:"ssh_host" cty:"ssh_host" hcl:"ssh_host"`
SSHPort *int `mapstructure:"ssh_port" cty:"ssh_port" hcl:"ssh_port"`
SSHUsername *string `mapstructure:"ssh_username" cty:"ssh_username" hcl:"ssh_username"`
SSHPassword *string `mapstructure:"ssh_password" cty:"ssh_password" hcl:"ssh_password"`
SSHKeyPairName *string `mapstructure:"ssh_keypair_name" undocumented:"true" cty:"ssh_keypair_name" hcl:"ssh_keypair_name"`
SSHTemporaryKeyPairName *string `mapstructure:"temporary_key_pair_name" undocumented:"true" cty:"temporary_key_pair_name" hcl:"temporary_key_pair_name"`
SSHTemporaryKeyPairType *string `mapstructure:"temporary_key_pair_type" cty:"temporary_key_pair_type" hcl:"temporary_key_pair_type"`
SSHTemporaryKeyPairBits *int `mapstructure:"temporary_key_pair_bits" cty:"temporary_key_pair_bits" hcl:"temporary_key_pair_bits"`
SSHCiphers []string `mapstructure:"ssh_ciphers" cty:"ssh_ciphers" hcl:"ssh_ciphers"`
SSHClearAuthorizedKeys *bool `mapstructure:"ssh_clear_authorized_keys" cty:"ssh_clear_authorized_keys" hcl:"ssh_clear_authorized_keys"`
SSHKEXAlgos []string `mapstructure:"ssh_key_exchange_algorithms" cty:"ssh_key_exchange_algorithms" hcl:"ssh_key_exchange_algorithms"`
SSHPrivateKeyFile *string `mapstructure:"ssh_private_key_file" undocumented:"true" cty:"ssh_private_key_file" hcl:"ssh_private_key_file"`
SSHCertificateFile *string `mapstructure:"ssh_certificate_file" cty:"ssh_certificate_file" hcl:"ssh_certificate_file"`
SSHPty *bool `mapstructure:"ssh_pty" cty:"ssh_pty" hcl:"ssh_pty"`
SSHTimeout *string `mapstructure:"ssh_timeout" cty:"ssh_timeout" hcl:"ssh_timeout"`
SSHWaitTimeout *string `mapstructure:"ssh_wait_timeout" undocumented:"true" cty:"ssh_wait_timeout" hcl:"ssh_wait_timeout"`
SSHAgentAuth *bool `mapstructure:"ssh_agent_auth" undocumented:"true" cty:"ssh_agent_auth" hcl:"ssh_agent_auth"`
SSHDisableAgentForwarding *bool `mapstructure:"ssh_disable_agent_forwarding" cty:"ssh_disable_agent_forwarding" hcl:"ssh_disable_agent_forwarding"`
SSHHandshakeAttempts *int `mapstructure:"ssh_handshake_attempts" cty:"ssh_handshake_attempts" hcl:"ssh_handshake_attempts"`
SSHBastionHost *string `mapstructure:"ssh_bastion_host" cty:"ssh_bastion_host" hcl:"ssh_bastion_host"`
SSHBastionPort *int `mapstructure:"ssh_bastion_port" cty:"ssh_bastion_port" hcl:"ssh_bastion_port"`
SSHBastionAgentAuth *bool `mapstructure:"ssh_bastion_agent_auth" cty:"ssh_bastion_agent_auth" hcl:"ssh_bastion_agent_auth"`
SSHBastionUsername *string `mapstructure:"ssh_bastion_username" cty:"ssh_bastion_username" hcl:"ssh_bastion_username"`
SSHBastionPassword *string `mapstructure:"ssh_bastion_password" cty:"ssh_bastion_password" hcl:"ssh_bastion_password"`
SSHBastionInteractive *bool `mapstructure:"ssh_bastion_interactive" cty:"ssh_bastion_interactive" hcl:"ssh_bastion_interactive"`
SSHBastionPrivateKeyFile *string `mapstructure:"ssh_bastion_private_key_file" cty:"ssh_bastion_private_key_file" hcl:"ssh_bastion_private_key_file"`
SSHBastionCertificateFile *string `mapstructure:"ssh_bastion_certificate_file" cty:"ssh_bastion_certificate_file" hcl:"ssh_bastion_certificate_file"`
SSHFileTransferMethod *string `mapstructure:"ssh_file_transfer_method" cty:"ssh_file_transfer_method" hcl:"ssh_file_transfer_method"`
SSHProxyHost *string `mapstructure:"ssh_proxy_host" cty:"ssh_proxy_host" hcl:"ssh_proxy_host"`
SSHProxyPort *int `mapstructure:"ssh_proxy_port" cty:"ssh_proxy_port" hcl:"ssh_proxy_port"`
SSHProxyUsername *string `mapstructure:"ssh_proxy_username" cty:"ssh_proxy_username" hcl:"ssh_proxy_username"`
SSHProxyPassword *string `mapstructure:"ssh_proxy_password" cty:"ssh_proxy_password" hcl:"ssh_proxy_password"`
SSHKeepAliveInterval *string `mapstructure:"ssh_keep_alive_interval" cty:"ssh_keep_alive_interval" hcl:"ssh_keep_alive_interval"`
SSHReadWriteTimeout *string `mapstructure:"ssh_read_write_timeout" cty:"ssh_read_write_timeout" hcl:"ssh_read_write_timeout"`
SSHRemoteTunnels []string `mapstructure:"ssh_remote_tunnels" cty:"ssh_remote_tunnels" hcl:"ssh_remote_tunnels"`
SSHLocalTunnels []string `mapstructure:"ssh_local_tunnels" cty:"ssh_local_tunnels" hcl:"ssh_local_tunnels"`
SSHPublicKey []byte `mapstructure:"ssh_public_key" undocumented:"true" cty:"ssh_public_key" hcl:"ssh_public_key"`
SSHPrivateKey []byte `mapstructure:"ssh_private_key" undocumented:"true" cty:"ssh_private_key" hcl:"ssh_private_key"`
WinRMUser *string `mapstructure:"winrm_username" cty:"winrm_username" hcl:"winrm_username"`
WinRMPassword *string `mapstructure:"winrm_password" cty:"winrm_password" hcl:"winrm_password"`
WinRMHost *string `mapstructure:"winrm_host" cty:"winrm_host" hcl:"winrm_host"`
WinRMNoProxy *bool `mapstructure:"winrm_no_proxy" cty:"winrm_no_proxy" hcl:"winrm_no_proxy"`
WinRMPort *int `mapstructure:"winrm_port" cty:"winrm_port" hcl:"winrm_port"`
WinRMTimeout *string `mapstructure:"winrm_timeout" cty:"winrm_timeout" hcl:"winrm_timeout"`
WinRMUseSSL *bool `mapstructure:"winrm_use_ssl" cty:"winrm_use_ssl" hcl:"winrm_use_ssl"`
WinRMInsecure *bool `mapstructure:"winrm_insecure" cty:"winrm_insecure" hcl:"winrm_insecure"`
WinRMUseNTLM *bool `mapstructure:"winrm_use_ntlm" cty:"winrm_use_ntlm" hcl:"winrm_use_ntlm"`
InstallerApp *string `mapstructure:"installer_app" cty:"installer_app" hcl:"installer_app"`
SourceVMName *string `mapstructure:"source_vm_name" cty:"source_vm_name" hcl:"source_vm_name"`
VMName *string `mapstructure:"vm_name" cty:"vm_name" hcl:"vm_name"`
DiskSize *string `mapstructure:"disk_size" cty:"disk_size" hcl:"disk_size"`
RAMSize *string `mapstructure:"ram_size" cty:"ram_size" hcl:"ram_size"`
CPUCount *string `mapstructure:"cpu_count" cty:"cpu_count" hcl:"cpu_count"`
PortForwardingRules []struct {
PortForwardingGuestPort int "mapstructure:\"port_forwarding_guest_port\""
PortForwardingHostPort int "mapstructure:\"port_forwarding_host_port\""
PortForwardingRuleName string "mapstructure:\"port_forwarding_rule_name\""
} `mapstructure:"port_forwarding_rules,omitempty" cty:"port_forwarding_rules" hcl:"port_forwarding_rules"`
HWUUID *string `mapstructure:"hw_uuid,omitempty" cty:"hw_uuid" hcl:"hw_uuid"`
BootDelay *string `mapstructure:"boot_delay" cty:"boot_delay" hcl:"boot_delay"`
EnableHtt *bool `mapstructure:"enable_htt" cty:"enable_htt" hcl:"enable_htt"`
DisableHtt *bool `mapstructure:"disable_htt" cty:"disable_htt" hcl:"disable_htt"`
UpdateAddons *bool `mapstructure:"update_addons" cty:"update_addons" hcl:"update_addons"`
UseAnkaCP *bool `mapstructure:"use_anka_cp" cty:"use_anka_cp" hcl:"use_anka_cp"`
}
FlatConfig is an auto-generated flat version of Config. Where the contents of a field with a `mapstructure:,squash` tag are bubbled up.
type StepConnectAnka ¶
type StepConnectAnka struct{}
func (*StepConnectAnka) Cleanup ¶
func (s *StepConnectAnka) Cleanup(state multistep.StateBag)
func (*StepConnectAnka) Run ¶
func (s *StepConnectAnka) Run(ctx context.Context, state multistep.StateBag) multistep.StepAction
type StepCreateVM ¶
type StepCreateVM struct {
// contains filtered or unexported fields
}
func (*StepCreateVM) Cleanup ¶
func (s *StepCreateVM) Cleanup(state multistep.StateBag)
func (*StepCreateVM) Run ¶
func (s *StepCreateVM) Run(ctx context.Context, state multistep.StateBag) multistep.StepAction
type StepSetHyperThreading ¶ added in v1.1.0
type StepSetHyperThreading struct{}
func (*StepSetHyperThreading) Cleanup ¶ added in v1.1.0
func (s *StepSetHyperThreading) Cleanup(state multistep.StateBag)
func (*StepSetHyperThreading) Run ¶ added in v1.1.0
func (s *StepSetHyperThreading) Run(ctx context.Context, state multistep.StateBag) multistep.StepAction
type StepStartVM ¶ added in v1.1.0
type StepStartVM struct{}
func (*StepStartVM) Cleanup ¶ added in v1.1.0
func (s *StepStartVM) Cleanup(state multistep.StateBag)
func (*StepStartVM) Run ¶ added in v1.1.0
func (s *StepStartVM) Run(ctx context.Context, state multistep.StateBag) multistep.StepAction
type StepTempDir ¶
type StepTempDir struct {
// contains filtered or unexported fields
}
StepTempDir creates a temporary directory that we use in order to share data with the anka vm over the communicator.
func (*StepTempDir) Cleanup ¶
func (s *StepTempDir) Cleanup(state multistep.StateBag)
func (*StepTempDir) Run ¶
func (s *StepTempDir) Run(ctx context.Context, state multistep.StateBag) multistep.StepAction
Click to show internal directories.
Click to hide internal directories.